@@ -13,31 +13,20 @@ from dateutil.relativedelta import relativedelta
 from trytond.transaction import Transaction
 from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
-from trytond.pyson import Bool, Eval, Or
+from trytond.pyson import Bool, Eval
 from nereid import request, cache, jsonify, abort, current_user, route
 from nereid.helpers import key_from_list
 
 __all__ = ['Product']
 __metaclass__ = PoolMeta
 
-STATES = {
-    'invisible': ~Bool(Eval('show_availability_message')),
-}
-DEPENDS = ['show_availability_message']
-
 
 class Product:
     "Product extension for Nereid"
     __name__ = "product.product"
 
-    show_availability_message = fields.Boolean(
-        "Show Availability On Website",
-        help="Show inventory status on website"
-    )
-
     display_available_quantity = fields.Boolean(
-        "Display Available Quantity On Website?",
-        states=STATES, depends=DEPENDS
+        "Display Available Quantity On Website?"
     )
 
     start_displaying_qty_digits = fields.Function(
@@ -48,13 +37,9 @@ class Product:
     start_displaying_available_quantity = fields.Numeric(
         'Start Quantity', digits=(16, Eval('start_displaying_qty_digits', 2)),
         states={
-            'invisible': Or(
-                ~Bool(Eval('show_availability_message')),
-                ~Bool(Eval('display_available_quantity')),
-            ),
+            'invisible': ~Bool(Eval('display_available_quantity')),
         }, depends=[
             'display_available_quantity', 'start_displaying_qty_digits',
-            'show_availability_message'
         ],
         help=(
             "Product's available quantity must be less than this to show on"
@@ -64,9 +49,17 @@ class Product:
 
     min_warehouse_quantity = fields.Numeric(
         'Min Warehouse Quantity', digits=(16, 4),
-        help="Minimum quantity required in warehouse for orders",
-        states=STATES, depends=DEPENDS
+        help="Minimum quantity required in warehouse for orders"
     )
+    is_backorder = fields.Function(
+        fields.Boolean("Is Backorder"), getter="get_is_backorder"
+    )
+
+    def get_is_backorder(self, name):
+        if self.min_warehouse_quantity is None or \
+                self.min_warehouse_quantity < 0:
+            return True
+        return False
 
     @classmethod
     def __setup__(cls):
